@@ -2,8 +2,8 @@ package ExtUtils::ExCxx;
 require Exporter;
 require DynaLoader;
 @ISA       = qw(Exporter DynaLoader);
-@EXPORT_OK = qw(&set_tryblock);
-$VERSION   = '0.01';
+@EXPORT_OK = qw(&set_tryblock &nest);
+$VERSION   = '0.02';
 
 bootstrap ExtUtils::ExCxx;
 
